@@ -3,8 +3,12 @@ import urllib.parse
 import urllib.request
 import os
 # API endpoint
-is_kubernetes = os.path.exists("/var/run/secrets/kubernetes.io")
-URL = "http://watchlog-node-agent:3774" if is_kubernetes else "http://127.0.0.1:3774"
+is_kubernetes = os.getenv('KUBERNETES_SERVICE_HOST') is not None
+URL = (
+    'http://watchlog-node-agent:3774'
+    if is_kubernetes
+    else 'http://localhost:3774'
+)
 
 class Watchlog:
     def __init__(self):
